m.css
#####

*A no-nonsense, no-JavaScript CSS framework, site and documentation theme for
content-oriented websites*

.. image:: https://badges.gitter.im/mosra/m.css.svg
    :alt: Join the chat at https://gitter.im/mosra/m.css
    :target: https://gitter.im/mosra/m.css?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
.. image:: https://circleci.com/gh/mosra/m.css.svg?style=shield
    :target: https://circleci.com/gh/mosra/m.css
.. image:: https://codecov.io/gh/mosra/m.css/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/mosra/m.css
.. image:: https://img.shields.io/badge/License-MIT-green.svg
    :alt: MIT License
    :target: https://opensource.org/licenses/MIT

Do you *hate* contemporary web development like I do? Do you also feel that
it's not right for a web page to take *seconds* and *megabytes* to render? Do
you want to write beautiful content but *can't* because the usual CMS tools
make your blood boil and so you rather stay silent? Well, I have something for
you.

Project website: https://mcss.mosra.cz

Pure CSS and HTML
=================

Everything you need is a few kilobytes of compressed CSS. This framework has
exactly 0 bytes of JavaScript because *nobody actually needs it*. Even for
responsive websites.

`Get the CSS <https://mcss.mosra.cz/css/>`_

Designed for content
====================

If you just want to write content with beautiful typography, you don't need
forms, progressbars, popups, dropdowns or other cruft. You want fast iteration
times.

`Use it with Pelican <https://mcss.mosra.cz/pelican/>`_

Authoring made easy
===================

Code snippets, math, linking to docs, presenting photography in a beautiful
way? Or making a complex page without even needing to touch HTML? Everything is
possible.

`Get Pelican plugins <https://mcss.mosra.cz/plugins/>`_

-------

*Still not convinced?* Head over to a `detailed explanation <https://mcss.mosra.cz/why/>`_
of this project goals and design decisions.

CONTRIBUTING
============

Head over to the `contribution guide <CONTRIBUTING.rst>`_ to see how to make
changes, verify the results and submit patches.

CONTACT
=======

Want to learn more about m.css? Found a bug or want to share an awesome idea?
Feel free to visit the project website or contact the author at:

-   Website --- https://mcss.mosra.cz
-   GitHub --- https://github.com/mosra/m.css
-   Gitter --- https://gitter.im/mosra/m.css
-   Twitter --- https://twitter.com/czmosra
-   E-mail --- mosra@centrum.cz

CREDITS
=======

See the `CREDITS.rst <CREDITS.rst>`_ file for details about contributors and
third-party code involved in this project. Big thanks to everyone involved!

LICENSE
=======

m.css is licensed under MIT/Expat license, see `COPYING <COPYING>`_ file for
details.
